@@ -29,6 +29,10 @@ def require_env(n: str, v: str = "") -> str:
     return v
 
 
+def next_job_id() -> str:
+    return str(uuid.uuid4())
+
+
 class TranscribeJobStatus(enum.Enum):
     NONE = 0
     UPLOADING = 1
@@ -41,13 +45,15 @@ class TranscribeJobStatus(enum.Enum):
 
 @dataclass
 class TranscribeJob:
+    batchId: str
     jobId: str
     sourceFile: str
     mediaFormat: str
-    batchId: str = ""
     languageCode: str = "en-US"
     status: TranscribeJobStatus = TranscribeJobStatus.NONE
     transcript: str = ""
+    generateSubtitles: bool = False
+    subtitles: str = ""
     error: str = ""
     info: Dict[str, str] = field(default_factory=lambda: {})
 
@@ -57,7 +63,7 @@ class TranscribeJob:
             self.status = TranscribeJobStatus[str(self.status)]
 
     def get_fq_id(self) -> str:
-        return f"{self.batchId}-{self.jobId}" if self.batchId else self.jobId
+        return f"{self.batchId}-{self.jobId}"
 
     def is_resolved(self) -> bool:
         return bool(
@@ -74,12 +80,10 @@ class TranscribeJobRequest:
     jobId: str = ""
     mediaFormat: str = ""
     languageCode: str = "en-US"
+    generateSubtitles: bool = False
 
     def __post_init__(self):
-        self.jobId = (
-            self.jobId
-            or f"{os.path.splitext(os.path.basename(self.sourceFile))[0]}-{uuid.uuid4()}"
-        )
+        self.jobId = self.jobId or next_job_id()
 
     def get_language_code(self, default_language_code: str = "en-US") -> str:
         return self.languageCode or default_language_code
@@ -91,7 +95,7 @@ class TranscribeJobRequest:
         return asdict(self)
 
     def to_job(
-        self, batch_id: str = "", status: TranscribeJobStatus = TranscribeJobStatus.NONE
+        self, batch_id: str, status: TranscribeJobStatus = TranscribeJobStatus.NONE
     ) -> TranscribeJob:
         return TranscribeJob(
             batchId=batch_id,
@@ -100,6 +104,7 @@ class TranscribeJobRequest:
             languageCode=self.get_language_code(),
             sourceFile=self.sourceFile,
             mediaFormat=self.get_media_format(),
+            generateSubtitles=self.generateSubtitles,
         )
 
 
@@ -168,6 +173,12 @@ class TranscribeBatchResult:
             and j.status in [TranscribeJobStatus.SUCCEEDED, TranscribeJobStatus.FAILED]
         )
 
+    def job_generates_subtitles(self, id: str, status: TranscribeJobStatus) -> bool:
+        if id not in id in self.transcribeJobsById:
+            return False
+        j = self.transcribeJobsById.get(id)
+        return bool(j and j.generateSubtitles)
+
     def jobs(self, ids: Iterable[str] = []) -> Iterable[TranscribeJob]:
         return (
             [self.transcribeJobsById[id] for id in ids if id in self.transcribeJobsById]
@@ -188,6 +199,7 @@ class TranscribeBatchResult:
         info: Dict[str, str] = {},
         transcript: str = "",
         error: str = "",
+        subtitles: str = "",
     ) -> bool:
         if id not in self.transcribeJobsById:
             raise Exception(
@@ -200,6 +212,7 @@ class TranscribeBatchResult:
         job_updated = TranscribeJob(**job_cur.to_dict())
         job_updated.status = status or TranscribeJobStatus.NONE
         job_updated.transcript = transcript or ""
+        job_updated.subtitles = subtitles or ""
         job_updated.error = error or ""
         job_updated.info = info or {}
         self.transcribeJobsById[id] = job_updated
